# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ostorlab/agent/message/proto/v3/report/cve/cve.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ostorlab/agent/message/proto/v3/report/cve/cve.proto',
  package='ostorlab.agent.message.proto.v3.report.cve',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4ostorlab/agent/message/proto/v3/report/cve/cve.proto\x12*ostorlab.agent.message.proto.v3.report.cve\"\xc1\x02\n\x07Message\x12\x0e\n\x06\x63ve_id\x18\x01 \x01(\t\x12\x43\n\x07targets\x18\x02 \x03(\x0b\x32\x32.ostorlab.agent.message.proto.v3.report.cve.Target\x12\x0b\n\x03\x63we\x18\x03 \x01(\x05\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12I\n\nreferences\x18\x05 \x03(\x0b\x32\x35.ostorlab.agent.message.proto.v3.report.cve.Reference\x12\x45\n\x0b\x63vss_scores\x18\x06 \x01(\x0b\x32\x30.ostorlab.agent.message.proto.v3.report.cve.CVSS\x12\x16\n\x0epublished_date\x18\x07 \x01(\x04\x12\x15\n\rmodified_date\x18\x08 \x01(\x04\"\x89\x02\n\x04\x43VSS\x12?\n\x03v31\x18\x01 \x01(\x0b\x32\x32.ostorlab.agent.message.proto.v3.report.cve.CVSSv3\x12?\n\x03v30\x18\x02 \x01(\x0b\x32\x32.ostorlab.agent.message.proto.v3.report.cve.CVSSv3\x12>\n\x02v2\x18\x03 \x01(\x0b\x32\x32.ostorlab.agent.message.proto.v3.report.cve.CVSSv2\x12?\n\x03v40\x18\x04 \x01(\x0b\x32\x32.ostorlab.agent.message.proto.v3.report.cve.CVSSv4\"\xdb\x05\n\x06\x43VSSv2\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x15\n\rvector_string\x18\x02 \x01(\t\x12\x1e\n\x16\x63onfidentiality_impact\x18\x03 \x01(\t\x12\x18\n\x10integrity_impact\x18\x04 \x01(\t\x12\x1b\n\x13\x61vailability_impact\x18\x05 \x01(\t\x12\x12\n\nbase_score\x18\x06 \x01(\x02\x12\x19\n\x11remediation_level\x18\x07 \x01(\t\x12\x19\n\x11report_confidence\x18\x08 \x01(\t\x12\x16\n\x0etemporal_score\x18\t \x01(\x02\x12#\n\x1b\x63onfidentiality_requirement\x18\n \x01(\t\x12\x1d\n\x15integrity_requirement\x18\x0b \x01(\t\x12 \n\x18\x61vailability_requirement\x18\x0c \x01(\t\x12\x1b\n\x13\x65nvironmental_score\x18\r \x01(\x02\x12\x15\n\raccess_vector\x18\x0e \x01(\t\x12\x19\n\x11\x61\x63\x63\x65ss_complexity\x18\x0f \x01(\t\x12\x16\n\x0e\x61uthentication\x18\x10 \x01(\t\x12\x16\n\x0e\x65xploitability\x18\x11 \x01(\t\x12#\n\x1b\x63ollateral_damage_potential\x18\x12 \x01(\t\x12\x1b\n\x13target_distribution\x18\x13 \x01(\t\x12\x14\n\x0cimpact_score\x18\x14 \x01(\x02\x12\x1c\n\x14\x65xploitability_score\x18\x15 \x01(\x02\x12\x15\n\rac_insuf_info\x18\x16 \x01(\x08\x12\x1c\n\x14obtain_all_privilege\x18\x17 \x01(\x08\x12\x1d\n\x15obtain_user_privilege\x18\x18 \x01(\x08\x12\x1e\n\x16obtain_other_privilege\x18\x19 \x01(\x08\x12!\n\x19user_interaction_required\x18\x1a \x01(\x08\"\xa0\x07\n\x06\x43VSSv3\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x15\n\rvector_string\x18\x02 \x01(\t\x12\x1e\n\x16\x63onfidentiality_impact\x18\x03 \x01(\t\x12\x18\n\x10integrity_impact\x18\x04 \x01(\t\x12\x1b\n\x13\x61vailability_impact\x18\x05 \x01(\t\x12\x12\n\nbase_score\x18\x06 \x01(\x02\x12\x19\n\x11remediation_level\x18\x07 \x01(\t\x12\x19\n\x11report_confidence\x18\x08 \x01(\t\x12\x16\n\x0etemporal_score\x18\t \x01(\x02\x12#\n\x1b\x63onfidentiality_requirement\x18\n \x01(\t\x12\x1d\n\x15integrity_requirement\x18\x0b \x01(\t\x12 \n\x18\x61vailability_requirement\x18\x0c \x01(\t\x12\x1b\n\x13\x65nvironmental_score\x18\r \x01(\x02\x12\x15\n\rattack_vector\x18\x0e \x01(\t\x12\x19\n\x11\x61ttack_complexity\x18\x0f \x01(\t\x12\x1b\n\x13privileges_required\x18\x10 \x01(\t\x12\x18\n\x10user_interaction\x18\x11 \x01(\t\x12\r\n\x05scope\x18\x12 \x01(\t\x12\x15\n\rbase_severity\x18\x13 \x01(\t\x12\x1d\n\x15\x65xploit_code_maturity\x18\x14 \x01(\t\x12\x19\n\x11temporal_severity\x18\x15 \x01(\t\x12\x1e\n\x16modified_attack_vector\x18\x16 \x01(\t\x12\"\n\x1amodified_attack_complexity\x18\x17 \x01(\t\x12$\n\x1cmodified_privileges_required\x18\x18 \x01(\t\x12!\n\x19modified_user_interaction\x18\x19 \x01(\t\x12\x16\n\x0emodified_scope\x18\x1a \x01(\t\x12\'\n\x1fmodified_confidentiality_impact\x18\x1b \x01(\t\x12!\n\x19modified_integrity_impact\x18\x1c \x01(\t\x12$\n\x1cmodified_availability_impact\x18\x1d \x01(\t\x12\x1e\n\x16\x65nvironmental_severity\x18\x1e \x01(\t\x12\x14\n\x0cimpact_score\x18\x1f \x01(\x02\x12\x1c\n\x14\x65xploitability_score\x18  \x01(\x02\"\xbc\t\n\x06\x43VSSv4\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x15\n\rvector_string\x18\x02 \x01(\t\x12\x12\n\nbase_score\x18\x03 \x01(\x02\x12\x15\n\rbase_severity\x18\x04 \x01(\t\x12\x15\n\rattack_vector\x18\x05 \x01(\t\x12\x19\n\x11\x61ttack_complexity\x18\x06 \x01(\t\x12\x1b\n\x13\x61ttack_requirements\x18\x07 \x01(\t\x12\x1b\n\x13privileges_required\x18\x08 \x01(\t\x12\x18\n\x10user_interaction\x18\t \x01(\t\x12)\n!vulnerable_system_confidentiality\x18\n \x01(\t\x12#\n\x1bvulnerable_system_integrity\x18\x0b \x01(\t\x12&\n\x1evulnerable_system_availability\x18\x0c \x01(\t\x12)\n!subsequent_system_confidentiality\x18\r \x01(\t\x12#\n\x1bsubsequent_system_integrity\x18\x0e \x01(\t\x12&\n\x1esubsequent_system_availability\x18\x0f \x01(\t\x12\x18\n\x10\x65xploit_maturity\x18\x10 \x01(\t\x12$\n\x1c\x63onfidentiality_requirements\x18\x11 \x01(\t\x12\x1e\n\x16integrity_requirements\x18\x12 \x01(\t\x12!\n\x19\x61vailability_requirements\x18\x13 \x01(\t\x12\x1e\n\x16modified_attack_vector\x18\x14 \x01(\t\x12\"\n\x1amodified_attack_complexity\x18\x15 \x01(\t\x12$\n\x1cmodified_attack_requirements\x18\x16 \x01(\t\x12$\n\x1cmodified_privileges_required\x18\x17 \x01(\t\x12!\n\x19modified_user_interaction\x18\x18 \x01(\t\x12\x32\n*modified_vulnerable_system_confidentiality\x18\x19 \x01(\t\x12,\n$modified_vulnerable_system_integrity\x18\x1a \x01(\t\x12/\n\'modified_vulnerable_system_availability\x18\x1b \x01(\t\x12\x32\n*modified_subsequent_system_confidentiality\x18\x1c \x01(\t\x12,\n$modified_subsequent_system_integrity\x18\x1d \x01(\t\x12/\n\'modified_subsequent_system_availability\x18\x1e \x01(\t\x12\x0e\n\x06safety\x18\x1f \x01(\t\x12\x13\n\x0b\x61utomatable\x18  \x01(\t\x12\x10\n\x08recovery\x18! \x01(\t\x12\x15\n\rvalue_density\x18\" \x01(\t\x12%\n\x1dvulnerability_response_effort\x18# \x01(\t\x12\x18\n\x10provider_urgency\x18$ \x01(\t\"6\n\tReference\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0c\n\x04tags\x18\x03 \x03(\t\"V\n\x0cVersionMatch\x12\r\n\x05start\x18\x01 \x01(\t\x12\x15\n\rstart_include\x18\x02 \x01(\x08\x12\x0b\n\x03\x65nd\x18\x03 \x01(\t\x12\x13\n\x0b\x65nd_include\x18\x04 \x01(\x08\"\x86\x02\n\x08\x43peMatch\x12\x0c\n\x04part\x18\x01 \x01(\t\x12\x0e\n\x06vendor\x18\x02 \x01(\t\x12\x0f\n\x07product\x18\x03 \x01(\t\x12I\n\x07version\x18\x04 \x01(\x0b\x32\x38.ostorlab.agent.message.proto.v3.report.cve.VersionMatch\x12\x0e\n\x06update\x18\x05 \x01(\t\x12\x0f\n\x07\x65\x64ition\x18\x06 \x01(\t\x12\x10\n\x08language\x18\x07 \x01(\t\x12\x12\n\nsw_edition\x18\x08 \x01(\t\x12\n\n\x02sw\x18\t \x01(\t\x12\n\n\x02hw\x18\n \x01(\t\x12\r\n\x05other\x18\x0b \x01(\t\x12\x12\n\nvulnerable\x18\x0c \x01(\x08\"S\n\x06Target\x12I\n\x0b\x63pe_matches\x18\x01 \x03(\x0b\x32\x34.ostorlab.agent.message.proto.v3.report.cve.CpeMatch'
)




_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='ostorlab.agent.message.proto.v3.report.cve.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cve_id', full_name='ostorlab.agent.message.proto.v3.report.cve.Message.cve_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targets', full_name='ostorlab.agent.message.proto.v3.report.cve.Message.targets', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cwe', full_name='ostorlab.agent.message.proto.v3.report.cve.Message.cwe', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ostorlab.agent.message.proto.v3.report.cve.Message.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='references', full_name='ostorlab.agent.message.proto.v3.report.cve.Message.references', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cvss_scores', full_name='ostorlab.agent.message.proto.v3.report.cve.Message.cvss_scores', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='published_date', full_name='ostorlab.agent.message.proto.v3.report.cve.Message.published_date', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_date', full_name='ostorlab.agent.message.proto.v3.report.cve.Message.modified_date', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=422,
)


_CVSS = _descriptor.Descriptor(
  name='CVSS',
  full_name='ostorlab.agent.message.proto.v3.report.cve.CVSS',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='v31', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSS.v31', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v30', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSS.v30', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v2', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSS.v2', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v40', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSS.v40', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=425,
  serialized_end=690,
)


_CVSSV2 = _descriptor.Descriptor(
  name='CVSSv2',
  full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vector_string', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.vector_string', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidentiality_impact', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.confidentiality_impact', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='integrity_impact', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.integrity_impact', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='availability_impact', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.availability_impact', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_score', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.base_score', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remediation_level', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.remediation_level', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='report_confidence', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.report_confidence', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temporal_score', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.temporal_score', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidentiality_requirement', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.confidentiality_requirement', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='integrity_requirement', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.integrity_requirement', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='availability_requirement', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.availability_requirement', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environmental_score', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.environmental_score', index=12,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_vector', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.access_vector', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_complexity', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.access_complexity', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authentication', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.authentication', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exploitability', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.exploitability', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collateral_damage_potential', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.collateral_damage_potential', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_distribution', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.target_distribution', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='impact_score', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.impact_score', index=19,
      number=20, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exploitability_score', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.exploitability_score', index=20,
      number=21, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ac_insuf_info', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.ac_insuf_info', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obtain_all_privilege', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.obtain_all_privilege', index=22,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obtain_user_privilege', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.obtain_user_privilege', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obtain_other_privilege', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.obtain_other_privilege', index=24,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_interaction_required', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv2.user_interaction_required', index=25,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=693,
  serialized_end=1424,
)


_CVSSV3 = _descriptor.Descriptor(
  name='CVSSv3',
  full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vector_string', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.vector_string', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidentiality_impact', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.confidentiality_impact', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='integrity_impact', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.integrity_impact', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='availability_impact', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.availability_impact', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_score', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.base_score', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remediation_level', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.remediation_level', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='report_confidence', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.report_confidence', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temporal_score', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.temporal_score', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidentiality_requirement', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.confidentiality_requirement', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='integrity_requirement', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.integrity_requirement', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='availability_requirement', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.availability_requirement', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environmental_score', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.environmental_score', index=12,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attack_vector', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.attack_vector', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attack_complexity', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.attack_complexity', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='privileges_required', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.privileges_required', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_interaction', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.user_interaction', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scope', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.scope', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_severity', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.base_severity', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exploit_code_maturity', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.exploit_code_maturity', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temporal_severity', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.temporal_severity', index=20,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_attack_vector', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.modified_attack_vector', index=21,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_attack_complexity', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.modified_attack_complexity', index=22,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_privileges_required', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.modified_privileges_required', index=23,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_user_interaction', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.modified_user_interaction', index=24,
      number=25, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_scope', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.modified_scope', index=25,
      number=26, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_confidentiality_impact', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.modified_confidentiality_impact', index=26,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_integrity_impact', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.modified_integrity_impact', index=27,
      number=28, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_availability_impact', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.modified_availability_impact', index=28,
      number=29, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environmental_severity', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.environmental_severity', index=29,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='impact_score', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.impact_score', index=30,
      number=31, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exploitability_score', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv3.exploitability_score', index=31,
      number=32, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1427,
  serialized_end=2355,
)


_CVSSV4 = _descriptor.Descriptor(
  name='CVSSv4',
  full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vector_string', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.vector_string', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_score', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.base_score', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_severity', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.base_severity', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attack_vector', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.attack_vector', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attack_complexity', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.attack_complexity', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attack_requirements', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.attack_requirements', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='privileges_required', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.privileges_required', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_interaction', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.user_interaction', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vulnerable_system_confidentiality', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.vulnerable_system_confidentiality', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vulnerable_system_integrity', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.vulnerable_system_integrity', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vulnerable_system_availability', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.vulnerable_system_availability', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subsequent_system_confidentiality', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.subsequent_system_confidentiality', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subsequent_system_integrity', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.subsequent_system_integrity', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subsequent_system_availability', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.subsequent_system_availability', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exploit_maturity', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.exploit_maturity', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidentiality_requirements', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.confidentiality_requirements', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='integrity_requirements', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.integrity_requirements', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='availability_requirements', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.availability_requirements', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_attack_vector', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.modified_attack_vector', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_attack_complexity', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.modified_attack_complexity', index=20,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_attack_requirements', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.modified_attack_requirements', index=21,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_privileges_required', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.modified_privileges_required', index=22,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_user_interaction', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.modified_user_interaction', index=23,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_vulnerable_system_confidentiality', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.modified_vulnerable_system_confidentiality', index=24,
      number=25, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_vulnerable_system_integrity', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.modified_vulnerable_system_integrity', index=25,
      number=26, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_vulnerable_system_availability', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.modified_vulnerable_system_availability', index=26,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_subsequent_system_confidentiality', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.modified_subsequent_system_confidentiality', index=27,
      number=28, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_subsequent_system_integrity', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.modified_subsequent_system_integrity', index=28,
      number=29, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_subsequent_system_availability', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.modified_subsequent_system_availability', index=29,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='safety', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.safety', index=30,
      number=31, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='automatable', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.automatable', index=31,
      number=32, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recovery', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.recovery', index=32,
      number=33, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_density', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.value_density', index=33,
      number=34, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vulnerability_response_effort', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.vulnerability_response_effort', index=34,
      number=35, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider_urgency', full_name='ostorlab.agent.message.proto.v3.report.cve.CVSSv4.provider_urgency', index=35,
      number=36, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2358,
  serialized_end=3570,
)


_REFERENCE = _descriptor.Descriptor(
  name='Reference',
  full_name='ostorlab.agent.message.proto.v3.report.cve.Reference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='ostorlab.agent.message.proto.v3.report.cve.Reference.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='ostorlab.agent.message.proto.v3.report.cve.Reference.source', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='ostorlab.agent.message.proto.v3.report.cve.Reference.tags', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3572,
  serialized_end=3626,
)


_VERSIONMATCH = _descriptor.Descriptor(
  name='VersionMatch',
  full_name='ostorlab.agent.message.proto.v3.report.cve.VersionMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='ostorlab.agent.message.proto.v3.report.cve.VersionMatch.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_include', full_name='ostorlab.agent.message.proto.v3.report.cve.VersionMatch.start_include', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='ostorlab.agent.message.proto.v3.report.cve.VersionMatch.end', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_include', full_name='ostorlab.agent.message.proto.v3.report.cve.VersionMatch.end_include', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3628,
  serialized_end=3714,
)


_CPEMATCH = _descriptor.Descriptor(
  name='CpeMatch',
  full_name='ostorlab.agent.message.proto.v3.report.cve.CpeMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='part', full_name='ostorlab.agent.message.proto.v3.report.cve.CpeMatch.part', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vendor', full_name='ostorlab.agent.message.proto.v3.report.cve.CpeMatch.vendor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product', full_name='ostorlab.agent.message.proto.v3.report.cve.CpeMatch.product', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='ostorlab.agent.message.proto.v3.report.cve.CpeMatch.version', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update', full_name='ostorlab.agent.message.proto.v3.report.cve.CpeMatch.update', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='edition', full_name='ostorlab.agent.message.proto.v3.report.cve.CpeMatch.edition', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='ostorlab.agent.message.proto.v3.report.cve.CpeMatch.language', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sw_edition', full_name='ostorlab.agent.message.proto.v3.report.cve.CpeMatch.sw_edition', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sw', full_name='ostorlab.agent.message.proto.v3.report.cve.CpeMatch.sw', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hw', full_name='ostorlab.agent.message.proto.v3.report.cve.CpeMatch.hw', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='other', full_name='ostorlab.agent.message.proto.v3.report.cve.CpeMatch.other', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vulnerable', full_name='ostorlab.agent.message.proto.v3.report.cve.CpeMatch.vulnerable', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3717,
  serialized_end=3979,
)


_TARGET = _descriptor.Descriptor(
  name='Target',
  full_name='ostorlab.agent.message.proto.v3.report.cve.Target',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cpe_matches', full_name='ostorlab.agent.message.proto.v3.report.cve.Target.cpe_matches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3981,
  serialized_end=4064,
)

_MESSAGE.fields_by_name['targets'].message_type = _TARGET
_MESSAGE.fields_by_name['references'].message_type = _REFERENCE
_MESSAGE.fields_by_name['cvss_scores'].message_type = _CVSS
_CVSS.fields_by_name['v31'].message_type = _CVSSV3
_CVSS.fields_by_name['v30'].message_type = _CVSSV3
_CVSS.fields_by_name['v2'].message_type = _CVSSV2
_CVSS.fields_by_name['v40'].message_type = _CVSSV4
_CPEMATCH.fields_by_name['version'].message_type = _VERSIONMATCH
_TARGET.fields_by_name['cpe_matches'].message_type = _CPEMATCH
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
DESCRIPTOR.message_types_by_name['CVSS'] = _CVSS
DESCRIPTOR.message_types_by_name['CVSSv2'] = _CVSSV2
DESCRIPTOR.message_types_by_name['CVSSv3'] = _CVSSV3
DESCRIPTOR.message_types_by_name['CVSSv4'] = _CVSSV4
DESCRIPTOR.message_types_by_name['Reference'] = _REFERENCE
DESCRIPTOR.message_types_by_name['VersionMatch'] = _VERSIONMATCH
DESCRIPTOR.message_types_by_name['CpeMatch'] = _CPEMATCH
DESCRIPTOR.message_types_by_name['Target'] = _TARGET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'ostorlab.agent.message.proto.v3.report.cve.cve_pb2'
  # @@protoc_insertion_point(class_scope:ostorlab.agent.message.proto.v3.report.cve.Message)
  })
_sym_db.RegisterMessage(Message)

CVSS = _reflection.GeneratedProtocolMessageType('CVSS', (_message.Message,), {
  'DESCRIPTOR' : _CVSS,
  '__module__' : 'ostorlab.agent.message.proto.v3.report.cve.cve_pb2'
  # @@protoc_insertion_point(class_scope:ostorlab.agent.message.proto.v3.report.cve.CVSS)
  })
_sym_db.RegisterMessage(CVSS)

CVSSv2 = _reflection.GeneratedProtocolMessageType('CVSSv2', (_message.Message,), {
  'DESCRIPTOR' : _CVSSV2,
  '__module__' : 'ostorlab.agent.message.proto.v3.report.cve.cve_pb2'
  # @@protoc_insertion_point(class_scope:ostorlab.agent.message.proto.v3.report.cve.CVSSv2)
  })
_sym_db.RegisterMessage(CVSSv2)

CVSSv3 = _reflection.GeneratedProtocolMessageType('CVSSv3', (_message.Message,), {
  'DESCRIPTOR' : _CVSSV3,
  '__module__' : 'ostorlab.agent.message.proto.v3.report.cve.cve_pb2'
  # @@protoc_insertion_point(class_scope:ostorlab.agent.message.proto.v3.report.cve.CVSSv3)
  })
_sym_db.RegisterMessage(CVSSv3)

CVSSv4 = _reflection.GeneratedProtocolMessageType('CVSSv4', (_message.Message,), {
  'DESCRIPTOR' : _CVSSV4,
  '__module__' : 'ostorlab.agent.message.proto.v3.report.cve.cve_pb2'
  # @@protoc_insertion_point(class_scope:ostorlab.agent.message.proto.v3.report.cve.CVSSv4)
  })
_sym_db.RegisterMessage(CVSSv4)

Reference = _reflection.GeneratedProtocolMessageType('Reference', (_message.Message,), {
  'DESCRIPTOR' : _REFERENCE,
  '__module__' : 'ostorlab.agent.message.proto.v3.report.cve.cve_pb2'
  # @@protoc_insertion_point(class_scope:ostorlab.agent.message.proto.v3.report.cve.Reference)
  })
_sym_db.RegisterMessage(Reference)

VersionMatch = _reflection.GeneratedProtocolMessageType('VersionMatch', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONMATCH,
  '__module__' : 'ostorlab.agent.message.proto.v3.report.cve.cve_pb2'
  # @@protoc_insertion_point(class_scope:ostorlab.agent.message.proto.v3.report.cve.VersionMatch)
  })
_sym_db.RegisterMessage(VersionMatch)

CpeMatch = _reflection.GeneratedProtocolMessageType('CpeMatch', (_message.Message,), {
  'DESCRIPTOR' : _CPEMATCH,
  '__module__' : 'ostorlab.agent.message.proto.v3.report.cve.cve_pb2'
  # @@protoc_insertion_point(class_scope:ostorlab.agent.message.proto.v3.report.cve.CpeMatch)
  })
_sym_db.RegisterMessage(CpeMatch)

Target = _reflection.GeneratedProtocolMessageType('Target', (_message.Message,), {
  'DESCRIPTOR' : _TARGET,
  '__module__' : 'ostorlab.agent.message.proto.v3.report.cve.cve_pb2'
  # @@protoc_insertion_point(class_scope:ostorlab.agent.message.proto.v3.report.cve.Target)
  })
_sym_db.RegisterMessage(Target)


# @@protoc_insertion_point(module_scope)



"""Module for the root command: agent."""

from ostorlab.cli.agent.agent import agent
from ostorlab.cli.agent import build
from ostorlab.cli.agent import install
from ostorlab.cli.agent import healthcheck
from ostorlab.cli.agent import delete
from ostorlab.cli.agent import list as list_cli
from ostorlab.cli.agent import search as search_cli

__all__ = [
    "agent",
    "build",
    "install",
    "healthcheck",
    "delete",
    "list_cli",
    "search_cli",
]
